@@ -31,8 +31,6 @@
 /* the main program */
 int main(int argc, char * argv[])
 {
-    // init random generator
-    qsrand(time(nullptr));
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
